Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(442)

Unified Diff: remoting/client/frame_consumer.h

Issue 9146030: Revert 118790 - Compile error due to missing operator== on SkRegion (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/base/decoder_vp8.cc ('k') | remoting/client/frame_consumer_proxy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/client/frame_consumer.h
===================================================================
--- remoting/client/frame_consumer.h (revision 118791)
+++ remoting/client/frame_consumer.h (working copy)
@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -40,13 +40,13 @@
virtual void ReleaseFrame(media::VideoFrame* frame) = 0;
// OnPartialFrameOutput() is called every time at least one rectangle of
- // output is produced. The |frame| is guaranteed to have valid data for all
- // of |region|.
+ // output is produced. The |frame| is guaranteed to have valid data for every
+ // region included in the |rects| list.
//
// Both |frame| and |region| are guaranteed to be valid until the |done|
// callback is invoked.
virtual void OnPartialFrameOutput(media::VideoFrame* frame,
- SkRegion* region,
+ RectVector* rects,
const base::Closure& done) = 0;
private:
« no previous file with comments | « remoting/base/decoder_vp8.cc ('k') | remoting/client/frame_consumer_proxy.h » ('j') | no next file with comments »
@@ -40,13 +40,13 @@
//
- // Both |frame| and |region| are guaranteed to be valid until the |done|
+ // Both |frame| and |rects| are guaranteed to be valid until the |done|
// callback is invoked.
virtual void OnPartialFrameOutput(media::VideoFrame* frame,

Powered by Google App Engine
This is Rietveld 408576698